@@ -3,4 +3,6 @@ from pandas_ml_common.utils.value_utils import *
 from pandas_ml_common.utils.callable_utils import *
 from pandas_ml_common.utils.types import *
 from pandas_ml_common.utils.normalization import ReScaler
-from pandas_ml_common.utils.serialization_utils import serialize, deserialize, plot_to_html_img
\ No newline at end of file
+from pandas_ml_common.utils.serialization_utils import serialize, deserialize, plot_to_html_img
+from pandas_ml_common.utils.jupyther_utils import register_wirte_and_run_magic, notebook_name
+from pandas_ml_common.utils.numpy_utils import nans
